from django.contrib.gis.db import models
import datetime
from os.path import join

class BaseModel(models.Model):
    changed = models.DateTimeField(null=True, editable=False)
    created = models.DateTimeField(null=True, editable=False)
    is_openmumbai_model = True

    def save(self, *args, **kwargs):
        if not self.id:
            self.created = datetime.datetime.today()
        self.changed = datetime.datetime.today()
        if self.created == None:
            self.created = self.changed
        super(BaseModel, self).save(*args, **kwargs)

    def get_dict(self, *args, **kwargs):
        return {
            'id': self.id,
            'name': self.name
        }

    def get_geojson(self, srid=4326):
#        print srid
        if self.geometry is not None:
            geom = json.loads(self.geometry.transform(srid, True).geojson)
        else:
            geom = {}

        properties = self.get_dict()

        return {
            'type': 'Feature',
            'properties': properties,
            'geometry': geom
        }        


    @classmethod
    def import_from_csv(kls):
        import csv
        from settings import PROJECT_ROOT
        from django.db.models import CharField, TextField, IntegerField, DecimalField, FloatField
        from decimal import Decimal
        import json
        import pdb
        model_name = kls.__name__
        filename = join(PROJECT_ROOT, "../data/%s.csv" % model_name)
        error_file = open(join(PROJECT_ROOT, "../errors/%s.json" % model_name), "w")
        errors = []       
        fields = kls._meta.fields[3:] #get all fields (excluding first 3 - id, changed, created)
        CsvFile = csv.reader(open(filename), delimiter="\t")
        header = True
        for row in CsvFile:
            #silly, to check if is first row, then is header, omit.
            if header == True:
                header = False
                continue
            i = 0
            data = {}
            for col in row:
                field = fields[i]
                fieldname = field.name
                val = col.strip()
                if isinstance(field, IntegerField):
                    try:
                        val = int(val)
                    except:
                        errors.append(row)
                        val = 0
                elif isinstance(field, DecimalField):
                    try:
                        val = Decimal(val)
                    except:
                        errors.append(row)
                        val = 0.0
                elif isinstance(field, FloatField):
                    try:
                        val = float(val)
                    except:
                        errors.append(row)
                        val = 0.0
                data[fieldname] = val
                i += 1
            #pdb.set_trace()
            obj = kls(**data) #FIXME: make this get_or_create
            obj.save()
                            
        error_file.write(json.dumps(errors, indent=2))
        error_file.close()
        print "imported %ss" % model_name

    class Meta:
        abstract = True

